@@ -316,11 +316,11 @@ class TalosHttpClient(TTransportBase):
 
     def open(self):
         if self.scheme == 'http':
-            self.__http = http_client.HTTPConnection(self.host, self.port,
-                                                     timeout=self.__timeout)
+            self.__http = http_client.HTTPConnection(self.get_addr_by_host(self.host),
+                                                     self.port, timeout=self.__timeout)
         elif self.scheme == 'https':
-            self.__http = http_client.HTTPSConnection(self.host, self.port,
-                                                      key_file=self.keyfile,
+            self.__http = http_client.HTTPSConnection(self.get_addr_by_host(self.host),
+                                                      self.port, key_file=self.keyfile,
                                                       cert_file=self.certfile,
                                                       timeout=self.__timeout,
                                                       context=self.context)
