@@ -37,23 +37,22 @@ class TalosProducer(object):
     logger = logging.getLogger("TalosProducer")
     partitionKeyMinLen = Constants.TALOS_PARTITION_KEY_LENGTH_MINIMAL
     partitionKeyMaxLen = Constants.TALOS_PARTITION_KEY_LENGTH_MAXIMAL
-    requestId = AtomicLong(1)
-    globalLock = threading.Condition()
     partitionNumber = int
     curPartitionId = int
 
     messageCallbackExecutors = threading.Thread
     partitionCheckExecutor = threading.Timer
-    partitionSenderMap = dict()
 
     falconWriter = FalconWriter
     producerMonitorThread = threading.Timer
 
-    lock = threading.Lock()
-
     def __init__(self, producerConfig=None, credential=None, topicName=None, talosAdmin=None,
                  talosClientFactory=None, topicTalosResourceName=None, partitioner=None,
                  topicAbnormalCallback=None, userMessageCallback=None):
+        self.globalLock = threading.Condition()
+        self.requestId = AtomicLong(1)
+        self.partitionSenderMap = dict()
+        self.lock = threading.Lock()
         self.talosProducerConfig = producerConfig
         self.producerState = PRODUCER_STATE.ACTIVE
         if talosClientFactory:
